@@ -440,6 +440,7 @@ class Locale(object):
                                  self.langData['en_US'])[field]
 
     def getLangByField(self, field, value):
+        value = value or ""
         if field == 'locale':
             value = (value,value.replace('UTF-8','utf8'))
         else:
@@ -488,7 +489,7 @@ class VariableOsLocaleLocale(ReadonlyVariable, Locale):
             cmd_val = self.getFieldByLang('locale', locale_val)
         else:
             cmd_val = None
-        locale_val = getValueFromConfig(locale_file, self.env_var)
+        locale_val = getValueFromConfig(locale_file, self.env_var) or ""
         locale_val = locale_val.replace('UTF-8','utf8')
         if self.isValueInFieldExists('locale', locale_val):
             file_val = locale_val
